@@ -8,6 +8,8 @@ ButtonSelectDlg::ButtonSelectDlg(QWidget *parent) :
     m_ui->setupUi(this);
     this->setWindowTitle("Select button image");
     m_ui->selectPushButton->setDisabled(true);
+	 connect(m_ui->HWlistWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(setButtonsOnListWidget2(QListWidgetItem*)));
+    connect(m_ui->HWbuttonListWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(setButton()));
     loadThemes();
     defaultflag = false;
 }
@@ -17,24 +19,12 @@ ButtonSelectDlg::~ButtonSelectDlg()
     delete m_ui;
 }
 
-void ButtonSelectDlg::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-
 void ButtonSelectDlg::loadThemes()
 {
     themeDirList.clear();
-    QDir *themeDirs = new QDir(themesPath);
+    QDir themeDirs(themesPath);
 
-    themeDirList = themeDirs->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
+    themeDirList = themeDirs.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     themeDirList.insert(0,"default");
 
     for(int i = 0 ; i < themeDirList.count() ; i++) {
@@ -67,11 +57,11 @@ void ButtonSelectDlg::loadThemes()
             m_ui->HWlistWidget->show();
         }
 
-        connect(m_ui->HWlistWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(setBackgroundsOnListWidget2(QListWidgetItem*)));
+    
     }
 }
 
-void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
+void ButtonSelectDlg::setButtonsOnListWidget2(QListWidgetItem *item)
 {
     m_ui->selectPushButton->setDisabled(true);
     buttonDirList.clear();
@@ -81,13 +71,13 @@ void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
     m_ui->HWbuttonListWidget->clear();
 
     if(item->text() == "Default") {
-        QDir *currentThemeDir = new QDir(defaultButtonsPath);
-        buttonDirList = currentThemeDir->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
+        QDir currentThemeDir(defaultButtonsPath);
+        buttonDirList = currentThemeDir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
         defaultflag = true;
     }
     else {
-        QDir *currentThemeDir = new QDir(themesPath + themeDirList.at(themeIndex) +"/buttons/");
-        buttonDirList = currentThemeDir->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
+        QDir currentThemeDir(themesPath + themeDirList.at(themeIndex) +"/buttons/");
+        buttonDirList = currentThemeDir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
         defaultflag = false;
     }
 
@@ -127,7 +117,6 @@ void ButtonSelectDlg::setBackgroundsOnListWidget2(QListWidgetItem *item)
         m_ui->HWbuttonListWidget->insertItem(i, item);
         m_ui->HWbuttonListWidget->show();
     }
-    connect(m_ui->HWbuttonListWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(setButton()));
 }
 
 void ButtonSelectDlg::setButton()
@@ -150,9 +139,6 @@ void ButtonSelectDlg::setButton()
 
 void ButtonSelectDlg::on_selectPushButton_clicked()
 {
-    QString fileNameUnPressed;
-    QString fileNamePressed;
-    QString confFileName;
 
     if(defaultflag) {
         fileNameUnPressed = (defaultButtonsPath + buttonDirList.at(buttonIndex) + "/" + upButtonName);
