@@ -1,12 +1,10 @@
 #include "buttonwidget.h"
 
-ButtonWidget::ButtonWidget(QWidget *parent, const QString aFilenameUnpressed,const QString aFileNamePressed,
-                           const QString aConfFileName, const QString aButtonText, const QStringList commands, int time) : QWidget( parent )
+ButtonWidget::ButtonWidget(QWidget *parent, const QString &aFilenameUnpressed,const QString &aFileNamePressed,
+                           const QString &aConfFileName, const QString &aButtonText, const QStringList &commands, int time) : QWidget( parent )
 {
         allowText = false;
-        fileNamePressed = aFileNamePressed;
         fileNameUnPressed = aFilenameUnpressed;
-        confFileName = aConfFileName;
         buttonText = aButtonText;
         commandChain = commands;
         timeOut = time;
@@ -15,13 +13,12 @@ ButtonWidget::ButtonWidget(QWidget *parent, const QString aFilenameUnpressed,con
         textDownSize = 29;
         textUpWeight = 50;
         textDownWeight = 50;
-        textUpColor = new QColor(255,255,255);
-        textDownColor = new QColor(255,255,255);
+        textUpColor = QColor(255,255,255);
 
         if(fileNameUnPressed.contains(themesPath,Qt::CaseInsensitive)) {
             fileNameUnPressed = aFilenameUnpressed;
-            fileNamePressed = aFileNamePressed;
-            confFileName = aConfFileName;
+            if(!aFileNamePressed.isNull()) { fileNamePressed = aFileNamePressed; }
+            if(!aConfFileName.isNull()) { confFileName = aConfFileName; }
         }
         else checkButtonCommand();
 
@@ -48,15 +45,15 @@ ButtonWidget::ButtonWidget(QWidget *parent, const QString aFilenameUnpressed,con
         if(downFontFamily.isEmpty())
             downFontFamily = "sans-serif";
 
-        pressedPixmap = new QPixmap( fileNamePressed);
-        unpressedPixmap = new QPixmap( fileNameUnPressed);
+        pressedPixmap = QPixmap( fileNamePressed);
+        unpressedPixmap = QPixmap( fileNameUnPressed);
         if(buttonText.count() > 5) {
             textUpSize-=(buttonText.count()+1);
             textDownSize-=(buttonText.count()+1);
         }
-        textUpFont = new QFont(upFontFamily, textUpSize, textUpWeight, false);
-        textDownFont = new QFont(downFontFamily, textDownSize, textDownWeight, false);
-        this->resize(unpressedPixmap->width()+1,unpressedPixmap->height()+1);
+        textUpFont = QFont(upFontFamily, textUpSize, textUpWeight, false);
+        textDownFont = QFont(downFontFamily, textDownSize, textDownWeight, false);
+        this->resize(unpressedPixmap.width()+1,unpressedPixmap.height()+1);
         this->update();
 }
 
@@ -81,7 +78,7 @@ void ButtonWidget::process_line(QString line)
             int size = tempLine.indexOf("size=");
             int count = tempLine.count();
             tempLine.chop(count - size);
-            upFontFamily = tempLine;
+            upFontFamily = tempLine.trimmed();
         }
         if(line.contains("font_desc=",Qt::CaseInsensitive)) {
             QStringList list = line.split(QRegExp("\\b"));
@@ -91,8 +88,6 @@ void ButtonWidget::process_line(QString line)
                 textUpWeight = 50;
             if(list.contains("Bold",Qt::CaseInsensitive))
                 textUpWeight = 75;
-            upFontFamily = list.at(0);
-
         }
 
         if(line.contains("size=",Qt::CaseInsensitive)) {
@@ -146,7 +141,7 @@ void ButtonWidget::process_line(QString line)
             gU = lineForeground.mid(2,2).toInt(&ok,16);
             bU = lineForeground.mid(4,2).toInt(&ok,16);
 
-            textUpColor = new QColor(rU,gU,bU);
+            textUpColor = QColor(rU,gU,bU);
         }
     }
 
@@ -158,7 +153,7 @@ void ButtonWidget::process_line(QString line)
             int size = tempLine.indexOf("size=");
             int count = tempLine.count();
             tempLine.chop(count - size);
-            downFontFamily = tempLine;
+            downFontFamily = tempLine.trimmed();
         }
         if(line.contains("font_desc=",Qt::CaseInsensitive)) {
         QStringList list = line.split(QRegExp("\\b"));
@@ -213,19 +208,6 @@ void ButtonWidget::process_line(QString line)
             if(line.contains("Black",Qt::CaseInsensitive))
                 textDownWeight = 87;
         }
-        if(line.contains("foreground=",Qt::CaseInsensitive)) {
-            bool ok;
-            int i,r,g,b;
-            QString y = "foreground=";
-            i = line.indexOf(y);
-            line.remove(0,(i+13));
-
-            r = line.mid(0,2).toInt(&ok,16);
-            g = line.mid(2,2).toInt(&ok,16);
-            b = line.mid(4,2).toInt(&ok,16);
-
-            textDownColor = new QColor(r,g,b);
-        }
     }
 }
 
@@ -234,10 +216,10 @@ void ButtonWidget::paintEvent( QPaintEvent* event)
         QPainter p;
         p.begin(this);
         p.save();
-        p.drawPixmap(0, 0, *unpressedPixmap );
+        p.drawPixmap(0, 0, unpressedPixmap );
         if(allowText && !buttonText.contains("blank",Qt::CaseInsensitive)) {
-            p.setPen(*textUpColor);
-            p.setFont(*textUpFont);
+            p.setPen(textUpColor);
+            p.setFont(textUpFont);
             p.drawText(this->rect(),Qt::AlignCenter,buttonText);
         }
         p.restore();
@@ -246,28 +228,28 @@ void ButtonWidget::paintEvent( QPaintEvent* event)
 
 void ButtonWidget::checkButtonCommand()
 {
-        if(fileNameUnPressed.contains("up",Qt::CaseSensitive) && buttonText == "Up" || buttonText == "up")
+        if(fileNameUnPressed.contains("up",Qt::CaseSensitive) && buttonText == "Up" || buttonText == "up" || buttonText == "UP")
         {
             fileNameUnPressed = defaultButtonsPath + "up/unpressed.png";
             fileNamePressed = defaultButtonsPath + "up/pressed.png";
             confFileName = defaultButtonsPath + "up/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("down",Qt::CaseSensitive) && buttonText == "Down" || buttonText == "down")
+        if(fileNameUnPressed.contains("down",Qt::CaseSensitive) && buttonText == "Down" || buttonText == "down" || buttonText == "DOWN")
         {
             fileNameUnPressed = defaultButtonsPath + "down/unpressed.png";
             fileNamePressed = defaultButtonsPath + "down/pressed.png";
             confFileName = defaultButtonsPath + "down/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("left",Qt::CaseSensitive) && buttonText == "Left" || buttonText == "left")
+        if(fileNameUnPressed.contains("left",Qt::CaseSensitive) && buttonText == "Left" || buttonText == "left" || buttonText == "LEFT")
         {
             fileNameUnPressed = defaultButtonsPath + "left/unpressed.png";
             fileNamePressed = defaultButtonsPath + "left/pressed.png";
             confFileName = defaultButtonsPath + "left/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("right",Qt::CaseSensitive) && buttonText == "Right" || buttonText == "right")
+        if(fileNameUnPressed.contains("right",Qt::CaseSensitive) && buttonText == "Right" || buttonText == "right" || buttonText == "RIGHT")
         {
             fileNameUnPressed = defaultButtonsPath + "right/unpressed.png";
             fileNamePressed = defaultButtonsPath + "right/pressed.png";
@@ -372,13 +354,6 @@ void ButtonWidget::checkButtonCommand()
             confFileName = defaultButtonsPath + "right/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("play",Qt::CaseInsensitive) && fileNameUnPressed.contains("pause",Qt::CaseInsensitive))
-        {
-            fileNameUnPressed = defaultButtonsPath + "pause/unpressed.png";
-            fileNamePressed = defaultButtonsPath + "pause/pressed.png";
-            confFileName = defaultButtonsPath + "pause/button.conf";
-            return;
-        }
         if(fileNameUnPressed.contains("power",Qt::CaseInsensitive) || fileNameUnPressed == "ONOFF" || fileNameUnPressed == "ON/OFF" ||
            fileNameUnPressed == "on/off" || fileNameUnPressed == "On/Off")
         {
