@@ -9,8 +9,8 @@ CommandChainDlg::CommandChainDlg(QWidget *parent) :
 
     flag = false;
     raw_flag = false;
-    QDir *dir = new QDir(devicesPath);
-    models = dir->entryList(QDir::NoDotAndDotDot | QDir::Files, QDir::Name);
+    QDir dir(devicesPath);
+    models = dir.entryList(QDir::NoDotAndDotDot | QDir::Files, QDir::Name);
     m_ui->remoteListWidget->addItems(models);
     m_ui->remoteListWidget->sortItems(Qt::AscendingOrder);
     m_ui->deleteRemoteButton->setDisabled(true);
@@ -25,22 +25,6 @@ CommandChainDlg::~CommandChainDlg()
     delete m_ui;
 }
 
-void CommandChainDlg::changeEvent(QEvent *e)
-{
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-void CommandChainDlg::commandItemClicked(QListWidgetItem* item)
-{
-    emit signalAddCommand(item->text(),m_ui->remoteListWidget->currentItem()->text(),"1");
-    this->close();
-}
 void CommandChainDlg::getCommands(QListWidgetItem* item)
 {
     commands.clear();
@@ -64,16 +48,19 @@ void CommandChainDlg::getCommands(QListWidgetItem* item)
         else process_line(line);
     }
     file.close();
-    in.reset();
+}
+
+void CommandChainDlg::commandItemClicked(QListWidgetItem* item)
+{
+    emit signalAddCommand(item->text(),m_ui->remoteListWidget->currentItem()->text());
+    this->close();
 }
 void CommandChainDlg::process_line(QString line)
 {
-    if(line.contains("end codes", Qt::CaseInsensitive)) {
+    if(line.contains("end codes", Qt::CaseInsensitive))
            flag = false;
-       }
-    if(line.contains("end raw_codes", Qt::CaseInsensitive)) {
+    if(line.contains("end raw_codes", Qt::CaseInsensitive))
            raw_flag = false;
-       }
     if(flag) {
         if(line.contains("0x",Qt::CaseInsensitive)) {
             QString commandName = line;
@@ -109,11 +96,12 @@ void CommandChainDlg::deleteRemote()
 {
     remoteName = m_ui->remoteListWidget->currentItem()->text();
     confFileInUse = false;
-    QDir *lircDir = new QDir(remotesPath);
+    QDir lircDir(remotesPath);
 
-    lircConfs = lircDir->entryList(QDir::Files);
+    lircConfs = lircDir.entryList(QDir::Files);
 
     for(int i = 0 ; i < lircConfs.count() ; i++) {
+        if(confFileInUse) break;
 
         if(lircConfs.at(i) != "remotes.conf")
         {
@@ -130,6 +118,7 @@ void CommandChainDlg::deleteRemote()
                 while (!in.atEnd()) {
                     QString line = in.readLine();
                     read_line(line,i);
+                    if(confFileInUse) break;
                 }
                 file.close();
         }
@@ -197,8 +186,8 @@ void CommandChainDlg::on_downloadRemoteButton_clicked()
     DownloadRemoteDlg *dloadRmDlg = new DownloadRemoteDlg(this, false);
     dloadRmDlg->exec();
     delete dloadRmDlg;
-    QDir *dir = new QDir(devicesPath);
-    models = dir->entryList(QDir::NoDotAndDotDot | QDir::Files, QDir::Name);
+    QDir dir(devicesPath);
+    models = dir.entryList(QDir::NoDotAndDotDot | QDir::Files, QDir::Name);
     m_ui->remoteListWidget->clear();
     m_ui->commandlistWidget->clear();
     m_ui->remoteListWidget->addItems(models);
@@ -209,13 +198,29 @@ void CommandChainDlg::on_downloadRemoteButton_clicked()
 void CommandChainDlg::read_line(QString line, int readIndex)
 {
     if(line.contains("LircConfs:", Qt::CaseInsensitive))
-    {
-        if(line.contains(remoteName, Qt::CaseInsensitive))
         {
-            confFileInUse = true;
-            remoteUsingLircConf = lircConfs.at(readIndex);
-            remoteUsingLircConf.chop(5);
+            line.remove(0,11);
+            line.append(" ");
+            QStringList list;
+            QString temp("");
+            for(int i=0;i<line.count();i++) {
+
+            if(!line.at(i).isSpace())
+                temp.append(line.at(i));
+
+            else {
+                list.append(temp);
+                temp.clear();
+            }
+        }
+        for(int i=0;i<list.count();i++) {
+
+                if(list.at(i) == remoteName) {
+                    confFileInUse = true;
+                    remoteUsingLircConf = lircConfs.at(readIndex);
+                    remoteUsingLircConf.chop(5);
+                }
+                if(confFileInUse) break;
+            }
         }
-        else confFileInUse = false;
-    }
 }
