@@ -124,7 +124,7 @@ void CreateButtonDlg::setAddButtonText(QString text)
 }
 void CreateButtonDlg::on_unpressedPushButton_clicked()
 {
-    fileNameUp = QFileDialog::getOpenFileName(this, tr("Open Image"), "/home/user/MyDocs/qtirreco/themes/", tr("Image Files (*.png)"));
+    fileNameUp = QFileDialog::getOpenFileName(this, tr("Open Image"), themesPath, tr("Image Files (*.png)"));
     QPixmap pix(fileNameUp);
     if(!pix.isNull()) {
         m_ui->pressedPushButton->setEnabled(true);
@@ -138,7 +138,7 @@ void CreateButtonDlg::on_unpressedPushButton_clicked()
 void CreateButtonDlg::on_pressedPushButton_clicked()
 {
 
-    fileNameDown = QFileDialog::getOpenFileName(this, tr("Open Image"), "/home/user/MyDocs/qtirreco/themes/", tr("Image Files (*.png)"));
+    fileNameDown = QFileDialog::getOpenFileName(this, tr("Open Image"), themesPath, tr("Image Files (*.png)"));
     QPixmap pix(fileNameDown);
     if(!pix.isNull()) {
         m_ui->addPushButton->setEnabled(true);
