@@ -8,7 +8,7 @@ const QString remotesPath = "/home/user/MyDocs/qtirreco/Remotes/";
 const QString qtirrecoImage = "/home/user/.qtirreco/themes/default/bg/qtirreco/irreco_logo.png";
 const QString devicesPath = "/home/user/MyDocs/qtirreco/Devices/";
 const QString remotesConf = "/home/user/MyDocs/qtirreco/Remotes/remotes.conf";
-const QString lircpathsConf = "/home/user/MyDocs/qtirreco/lirchpaths.conf";
+const QString lircpathsConf = "/home/user/MyDocs/qtirreco/lircpaths.conf";
 const QString themesPath = "/home/user/MyDocs/qtirreco/.themes/";
 const QString defaultButtonsPath = "/home/user/.qtirreco/themes/default/buttons/";
 
