@@ -9,7 +9,6 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
     this->resize(800,424);
     setAcceptDrops(true);
     useModeEnabled = true;
-    buttonsVisible = true;
     snapToGridEnabled = false;
     vector = new QVector<ButtonWidget*>;
     bgPath = qtirrecoImage;
@@ -40,11 +39,6 @@ void LayoutWidget::setUseModeEnabled(bool useMode)
     }
 }
 
-void LayoutWidget::setButtonsVisible(bool menuButtonsVisible)
-{
-    buttonsVisible = menuButtonsVisible;
-}
-
 void LayoutWidget::openEditDlg()
 {
     NewButtonDlg *newButtonDlg = new NewButtonDlg(this,vector->at(currentButtonIndex), vector);
@@ -82,59 +76,56 @@ void LayoutWidget::snapToGrid()
 void LayoutWidget::mousePressEvent(QMouseEvent *event)
 {
     ButtonWidget *child = static_cast<ButtonWidget*>(childAt(event->pos()));
-    if (!child) {
-            emit showOrHideMenu();
-            return;
+    if(child) {
+        QPoint hotSpot = event->pos() - child->pos();
+        xPos = child->x();
+        yPos = child->y();
+    
+        QByteArray itemData;
+        QDataStream dataStream(&itemData, QIODevice::WriteOnly);
+        dataStream << QPoint(hotSpot) << (child->fileNameUnPressed) << (child->fileNamePressed) << (child->confFileName) << (child->buttonText) << (child->commandChain) << (child->timeOut);
+
+        QMimeData *mimeData = new QMimeData;
+        mimeData->setData("application/x-qtirreco", itemData);
+        mimeData->setText(child->fileNameUnPressed);
+
+        copyButton = child;
+        QDrag *drag = new QDrag(this);
+        drag->setMimeData(mimeData);
+
+        QPainter p;
+        p.begin(&copyButton->pressedPixmap);
+        p.save();
+        p.drawPixmap(0, 0, copyButton->pressedPixmap );
+        if(copyButton->allowText && !copyButton->buttonText.contains("blank",Qt::CaseInsensitive)) {
+            p.setPen(copyButton->textUpColor);
+            p.setFont(copyButton->textUpFont);
+            p.drawText(copyButton->rect(),Qt::AlignCenter,copyButton->buttonText);
         }
+        p.restore();
+        p.end();
 
-    QPoint hotSpot = event->pos() - child->pos();
-    xPos = child->x();
-    yPos = child->y();
+        drag->setPixmap(copyButton->pressedPixmap);
+        drag->setHotSpot(hotSpot);
 
-    QByteArray itemData;
-    QDataStream dataStream(&itemData, QIODevice::WriteOnly);
-    dataStream << QPoint(hotSpot) << (child->fileNameUnPressed) << (child->fileNamePressed) << (child->confFileName) << (child->buttonText) << (child->commandChain) << (child->timeOut);
+        if(useModeEnabled) {
 
-    QMimeData *mimeData = new QMimeData;
-    mimeData->setData("application/x-qtirreco", itemData);
-    mimeData->setText(child->fileNameUnPressed);
+            if(copyButton->commandChain.count() == 1)
+                    this->sendIrCommands(copyButton->commandChain);
+             drag->exec(Qt::IgnoreAction, Qt::IgnoreAction);
+        }
+        else {
 
-    copyButton = child;
-    QDrag *drag = new QDrag(this);
-    drag->setMimeData(mimeData);
-
-    QPainter p;
-    p.begin(copyButton->pressedPixmap);
-    p.save();
-    p.drawPixmap(0, 0, *copyButton->pressedPixmap );
-    if(copyButton->allowText && !copyButton->buttonText.contains("blank",Qt::CaseInsensitive)) {
-        p.setPen(*copyButton->textUpColor);
-        p.setFont(*copyButton->textUpFont);
-        p.drawText(copyButton->rect(),Qt::AlignCenter,copyButton->buttonText);
-    }
-    p.restore();
-    p.end();
-
-    drag->setPixmap(*copyButton->pressedPixmap);
-    drag->setHotSpot(hotSpot);
-
-    if(useModeEnabled) {
-
-        if(copyButton->commandChain.count() == 1)
-                this->sendIrCommands(copyButton->commandChain);
-         drag->exec(Qt::IgnoreAction, Qt::IgnoreAction);
-    }
-    else {
-
-        child->hide();
-        if (drag->exec(Qt::MoveAction | Qt::CopyAction, Qt::CopyAction) == Qt::MoveAction)
-            child->close();
-        else child->show();
+            child->hide();
+            if (drag->exec(Qt::MoveAction | Qt::CopyAction, Qt::CopyAction) == Qt::MoveAction)
+                child->close();
+            else child->show();
+        }
     }
  }
 
 void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
- {
+{
     if(useModeEnabled){
         if(copyButton->commandChain.count() > 1 && copyButton->underMouse())
             this->sendIrCommands(copyButton->commandChain);
@@ -157,20 +148,21 @@ void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
         event->ignore();
 
  }
+
  void LayoutWidget::dragMoveEvent(QDragMoveEvent *event)
  {
     if (event->mimeData()->hasFormat("application/x-qtirreco")) {
          if (children().contains(event->source())) {
              event->setDropAction(Qt::MoveAction);
              event->accept();
-         } else
-             event->acceptProposedAction();
-
-     } else if (event->mimeData()->hasText())
+         }
+         else event->acceptProposedAction();
+    }
+    else if (event->mimeData()->hasText())
          event->acceptProposedAction();
-      else
-         event->ignore();
+    else event->ignore();
  }
+
  void LayoutWidget::dropEvent(QDropEvent *event)
  {
 
@@ -263,15 +255,15 @@ void LayoutWidget::dragEnterEvent(QDragEnterEvent *event)
              menu->show();
          }
      }
-    else {
-        timer->stop();
-        }
+    else timer->stop();
 }
+
 void LayoutWidget::deleteButton()
 {
     vector->at(currentButtonIndex)->deleteLater();
     vector->remove(currentButtonIndex);
 }
+
 void LayoutWidget::clearScreen()
 {
     for (int i=0;i<vector->count();i++) {
@@ -279,6 +271,7 @@ void LayoutWidget::clearScreen()
     }
     vector->clear();
 }
+
 void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, QPoint position,int timeOut)
 {
      ButtonWidget *pw = new ButtonWidget(this, fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, timeOut);
