@@ -2,47 +2,32 @@
 #include "ui_qtirreco.h"
 
 QtIrreco::QtIrreco(QWidget *parent)
-    : QMainWindow(parent), ui(new Ui::QtIrrecoClass)
+    : QMainWindow(parent), m_ui(new Ui::QtIrrecoClass)
 {
-
+    m_ui->setupUi(this);
+    this->initMenu();
      //Creates empty remotes.conf file
     QFile file(remotesConf);
     if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
         return;
     file.close();
 
-    init = false;
-    showDatabaseButtons = false;
     remoteNames = new QStringList();
     lw = new LayoutWidget(this);
 
-    remoteIndex = 0;
-
     lw->show();
     lw->setFocus();
 
-    buttonVector = new QVector<QPushButton*>();
-    currentRemoteButtonIndex = 0;
-    remoteButtonsVisible = false;
-
-    connect(lw,SIGNAL(showOrHideMenu()),this,SLOT(showOrHideButtons()));
     connect(this,SIGNAL(remoteNameToLw(QString)),lw,SLOT(setActiveRemoteName(QString)));
     connect(this,SIGNAL(bgImageToLw(QString)),lw,SLOT(setBackgroundImagePath(QString)));
     connect(this,SIGNAL(rgbToLw(int,int,int)),lw,SLOT(setRgbInteger(int,int,int)));
     connect(this,SIGNAL(remoteDeleted()),lw,SLOT(clearScreen()));
 
-    createButtons();
-    connectButtons();
-
-    showUseModeButtons();
-    hideEditModeButtons();
     useModeEnabled = true;
-    buttonsVisible = true;
-
 
    this->checkForRemotes();
    if(remoteNames->count() != 0) {
-       this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
+       this->setWindowTitle("QtIrreco:"+activeRemote);
        this->setActiveRemote();
     }
 
@@ -54,7 +39,7 @@ QtIrreco::~QtIrreco()
 {
     // Stop lirc server
     system("sudo /etc/init.d/lirc stop");
-    delete ui;
+    delete m_ui;
 
 }
 void QtIrreco::setActiveRemote()
@@ -74,7 +59,6 @@ void QtIrreco::setActiveRemote()
 
 void QtIrreco::checkForRemotes()
 {
-    remoteIndex = 0;
     QDir dir;
 
     QFile file(remotesConf);
@@ -88,7 +72,6 @@ void QtIrreco::checkForRemotes()
         QString line = in.readLine();
         process_line(line);
     }
-    init = true;
     file.close();
 }
 
@@ -112,9 +95,10 @@ void QtIrreco::noRemotes()
          return;
      file.close();
 
-     editButton->setDisabled(true);
-     showButton->setDisabled(true);
-     deleteButton->setDisabled(true);
+     m_ui->actionEditRemote->setDisabled(true);
+     m_ui->actionSelectRemote->setDisabled(true);
+     m_ui->actionDeleteRemote->setDisabled(true);
+     m_ui->actionUploadDb->setDisabled(true);
 
      QColor defaultBgColor(50,50,50);
      palette.setColor(QPalette::Window,defaultBgColor);
@@ -126,116 +110,13 @@ void QtIrreco::noRemotes()
      lw->setAutoFillBackground(true);
 }
 
-void QtIrreco::showOrHideButtons()
-{
-    if(useModeEnabled) {
-        if(buttonsVisible) {
-            hideUseModeButtons();
-            this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to show menu");
-        }
-        else if(!buttonsVisible) {
-            showUseModeButtons();
-            this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
-        }
-    }
-    if(!useModeEnabled) {
-        if(buttonsVisible) {
-            hideEditModeButtons();
-            this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to show menu");
-        }
-        else if(!buttonsVisible) {
-            showEditModeButtons();
-            this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
-        }
-    }
-}
-
-void QtIrreco::hideEditModeButtons()
-{
-    saveButton->hide();
-    newPushButton->hide();
-    renameButton->hide();
-    backgroundButton->hide();
-    snapButton->hide();
-    buttonsVisible = false;
-    lw->setButtonsVisible(buttonsVisible);
-}
-
-void QtIrreco::showEditModeButtons()
-{
-    saveButton->show();
-    newPushButton->show();
-    renameButton->show();
-    backgroundButton->show();
-    snapButton->show();
-    buttonsVisible = true;
-}
-
-void QtIrreco::hideUseModeButtons()
-{
-    themeButton->hide();
-    editButton->hide();
-    dataBaseButton->hide();
-    newRemoteButton->hide();
-    downloadButton->hide();
-    deleteButton->hide();
-    showButton->hide();
-    aboutButton->hide();
-    downDBButton->hide();
-    upDBButton->hide();
-
-    if(remoteButtonsVisible) {
-        if(remoteNames->count() > 4) {
-            for(int i=currentRemoteButtonIndex;i<currentRemoteButtonIndex+4;i++) {
-                buttonVector->at(i)->hide();
-                remoteScrollBar->deleteLater();
-            }
-        }
-        if(remoteNames->count() <= 4) {
-            for(int i=0;i<remoteNames->count();i++)
-                buttonVector->at(i)->hide();
-
-        }
-    }
-    buttonVector->clear();
-    buttonsVisible = false;
-}
-
-void QtIrreco::showUseModeButtons()
-{
-    themeButton->show();
-    editButton->show();
-    dataBaseButton->show();
-    newRemoteButton->show();
-    downloadButton->show();
-    deleteButton->show();
-    showButton->show();
-    aboutButton->show();
-    dataBaseButton->show();
-    // downDBButton and UpDBButton are shown when dataBaseButton is pressed
-    if(showDatabaseButtons) {
-        downDBButton->show();
-        upDBButton->show();
-    }
-    else {
-        downDBButton->hide();
-        upDBButton->hide();
-    }
-
-    if(remoteButtonsVisible) {
-        remoteButtonsVisible=false;
-        this->showRemote();
-    }
-    buttonsVisible = true;
-}
-
 void QtIrreco::newRemote() // Using RenameRemoteDlg class
 {
     RenameRemoteDlg *rrDlg = new RenameRemoteDlg(this,activeRemote);
     rrDlg->setWindowTitle("Create a new remote");
     rrDlg->setNameLabelText("Please enter remote name: ");
-    rrDlg->setLabelGeometry(270,10,360,31);
     rrDlg->setPushButtonText("Create remote");
+    rrDlg->setLabelGeometry(260,10,360,31);
     connect(rrDlg,SIGNAL(newRemote(QString)),this,SLOT(createRemote(QString)));
     rrDlg->exec();
     delete rrDlg;
@@ -243,15 +124,6 @@ void QtIrreco::newRemote() // Using RenameRemoteDlg class
 
 void QtIrreco::createRemote(QString newRemoteName)
 {
-    themeButton->setEnabled(true);
-    editButton->setEnabled(true);
-    dataBaseButton->setEnabled(true);
-    showButton->setEnabled(true);
-    deleteButton->setEnabled(true);
-    aboutButton->setEnabled(true);
-    downloadButton->setEnabled(true);
-    upDBButton->setEnabled(true);
-    downDBButton->setEnabled(true);
     bool alreadyExists = false;
     QString newRemoteFileName = (newRemoteName+".conf");
     for(int i=0;i<remoteNames->count();i++) {
@@ -284,27 +156,27 @@ void QtIrreco::createRemote(QString newRemoteName)
 
         remoteNames->append(newRemoteName+".conf");
 
-         activeRemote = newRemoteName;
-         lw->setActiveRemoteName(activeRemote);
-         writeRemoteChanges();
-         this->hideUseModeButtons();
-         this->showEditModeButtons();
-         lw->setUseModeEnabled(false);
-         useModeEnabled = false;
-         this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
-         newRemoteFile.close();
-         lw->saveRemoteToFile();
+        m_ui->actionEditRemote->setEnabled(true);
+        m_ui->actionDeleteRemote->setEnabled(true);
+        m_ui->actionSelectRemote->setEnabled(true);
+        m_ui->actionUploadDb->setEnabled(true);
+
+        activeRemote = newRemoteName;
+        lw->setActiveRemoteName(activeRemote);
+        writeRemoteChanges();
+        lw->setUseModeEnabled(false);
+        useModeEnabled = false;
+        this->setWindowTitle("QtIrreco:"+activeRemote);
+        newRemoteFile.close();
+        lw->saveRemoteToFile();
         }
 }
 
 void QtIrreco::editRemote()
 {
-    this->showEditModeButtons();
-    this->hideUseModeButtons();
+    this->enableEditMenu();
     useModeEnabled = false;
     lw->setUseModeEnabled(useModeEnabled);
-    buttonsVisible = true;
-    this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
     lw->setFocus();
 
     // emits background properties to layout in case no background changes are made so saving file works.
@@ -333,13 +205,18 @@ void QtIrreco::changeNewRemoteName(QString newName)
     if(alreadyExists) {
             QMessageBox::warning(this,"Remote name already exists!","Please choose different remote name.",
                          QMessageBox::NoButton,QMessageBox::NoButton);
+            RenameRemoteDlg *rrDlg = new RenameRemoteDlg(this,activeRemote);
+            connect(rrDlg,SIGNAL(changeName(QString)),this,SLOT(changeNewRemoteName(QString)));
+            rrDlg->setLabelGeometry(230,10,360,31);
+            rrDlg->exec();
+            delete rrDlg;
     }
     else {
         oldRemoteName = activeRemote;
         QFile remoteFile(remotesPath + oldRemoteName + ".conf");
         remoteFile.rename(newName+".conf");
         activeRemote = newName;
-        this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
+        this->setWindowTitle("QtIrreco:"+activeRemote);
         lw->setActiveRemoteName(activeRemote);
         for(int i=0;i<remoteNames->count();i++) {
             if(remoteNames->at(i).contains(oldRemoteName))
@@ -347,10 +224,9 @@ void QtIrreco::changeNewRemoteName(QString newName)
 
         }
         this->saveRemote();
-        this->hideUseModeButtons();
-        this->showEditModeButtons();
         useModeEnabled = false;
         lw->setUseModeEnabled(useModeEnabled);
+        this->editRemote();
         // Make changes to remotes.conf
         writeRemoteChanges();
 
@@ -388,11 +264,12 @@ void QtIrreco::addRemoteName(QString newRemoteName)
 {
     remoteNames->append(newRemoteName+".conf");
     activeRemote = newRemoteName;
-    editButton->setEnabled(true);
-    showButton->setEnabled(true);
-    deleteButton->setEnabled(true);
 
-    buttonsVisible = true;
+    m_ui->actionEditRemote->setEnabled(true);
+    m_ui->actionSelectRemote->setEnabled(true);
+    m_ui->actionDeleteRemote->setEnabled(true);
+    m_ui->actionUploadDb->setEnabled(true);
+
     lw->setFocus();
     lw->setBackgroundImagePath(qtirrecoImage);
     backgroundMode = defaultBackground;
@@ -408,40 +285,40 @@ void QtIrreco::addRemoteName(QString newRemoteName)
     lw->setAutoFillBackground(true);
 
     this->setActiveRemote();
-    this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
+    this->setWindowTitle("QtIrreco:"+activeRemote);
 
     writeRemoteChanges();
     this->saveRemote();
-    this->hideUseModeButtons();
 }
 
 void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number)
 {
-    themeButton->setEnabled(true);
-    showButton->setEnabled(true);
-    deleteButton->setEnabled(true);
-    aboutButton->setEnabled(true);
-    editButton->setEnabled(true);
-    downloadButton->setEnabled(true);
-    dataBaseButton->setEnabled(true);
-    upDBButton->setEnabled(true);
-    downDBButton->setEnabled(true);
     lw->addButton(fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, number);
 }
 void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number,int timeOut)
 {
-    themeButton->setEnabled(true);
-    showButton->setEnabled(true);
-    deleteButton->setEnabled(true);
-    aboutButton->setEnabled(true);
-    editButton->setEnabled(true);
-    downloadButton->setEnabled(true);
-    dataBaseButton->setEnabled(true);
-    upDBButton->setEnabled(true);
-    downDBButton->setEnabled(true);
     lw->addButton(fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, QPoint(0,0), timeOut);
 }
 
+void QtIrreco::selectRemote()
+{
+    ChangeRemoteDlg *crDlg = new ChangeRemoteDlg(this, remoteNames);
+    connect(crDlg,SIGNAL(setActiveRemoteText(QString)),this,SLOT(setActiveRemoteText(QString)));
+    crDlg->exec();
+    crDlg->deleteLater();
+}
+
+void QtIrreco::setActiveRemoteText(QString name)
+{
+    activeRemote.clear();
+    activeRemote = name;
+
+    lw->clearScreen();
+    this->setActiveRemote();
+    this->writeRemoteChanges();
+
+    this->setWindowTitle("QtIrreco:"+activeRemote);
+}
 
 void QtIrreco::deleteRemote() // Using RenameRemoteDlg class
 {
@@ -449,9 +326,9 @@ void QtIrreco::deleteRemote() // Using RenameRemoteDlg class
     rrDlg->setGeometry(0,0,800,175);
     rrDlg->setWindowTitle("Delete remote");
     rrDlg->setNameLabelText("Are you sure you wish to delete remote: "+activeRemote+" ?");
-    rrDlg->setLabelGeometry(200,25,600,50);
+    rrDlg->setLabelGeometry(150,25,600,50);
     rrDlg->setPushButtonText("Delete");
-    rrDlg->setPushButtonGeometry(300,85,200,75);
+    rrDlg->setPushButtonGeometry(300,85,200,60);
     rrDlg->hideLineEdit();
     connect(rrDlg,SIGNAL(deleteRemote()),this,SLOT(deleteActiveRemote()));
     rrDlg->exec();
@@ -469,15 +346,13 @@ void QtIrreco::deleteActiveRemote()
             remoteNames->removeAt(i);
 
     }
-    buttonVector->clear();
-    showRemoteButtons();
 
     if(remoteNames->count() > 0) {
         activeRemote = remoteNames->at(0);
         activeRemote.chop(5);
         this->setActiveRemote();
         lw->setActiveRemoteName(activeRemote);
-        this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
+        this->setWindowTitle("QtIrreco:"+activeRemote);
     }
     this->writeRemoteChanges();
     this->checkForRemotes();
@@ -513,12 +388,9 @@ void QtIrreco::newButton()
 
 void QtIrreco::saveRemote()
 {
-    this->hideUseModeButtons();
-    this->hideEditModeButtons();
+    this->enableUseMenu();
     useModeEnabled = true;
     lw->setUseModeEnabled(useModeEnabled);
-    buttonsVisible = false;
-    this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
     lw->setFocus();
     lw->saveRemoteToFile();
     lircFileNames.clear();
@@ -599,100 +471,12 @@ void QtIrreco::uploadDB()
     UploadDBDlg *uploadDlg = new UploadDBDlg(this, activeRemote);
     uploadDlg->exec();
     delete uploadDlg;
-    downDBButton->hide();
-    upDBButton->hide();
-    themeButton->setEnabled(true);
-    editButton->setEnabled(true);
-    dataBaseButton->setEnabled(true);
-    newRemoteButton->setEnabled(true);
-    downloadButton->setEnabled(true);
-    deleteButton->setEnabled(true);
-    showButton->setEnabled(true);
-    aboutButton->setEnabled(true);
-    showDatabaseButtons = false;
-}
-void QtIrreco::showDBButtons()
-{
-    if(showDatabaseButtons) {
-        downDBButton->hide();
-        upDBButton->hide();
-        showDatabaseButtons = false;
-    }
-    else {
-        downDBButton->show();
-        upDBButton->show();
-        showDatabaseButtons = true;
-    }
-
-    if(aboutButton->isEnabled()) {
-        themeButton->setDisabled(true);
-        editButton->setDisabled(true);
-        newRemoteButton->setDisabled(true);
-        downloadButton->setDisabled(true);
-        deleteButton->setDisabled(true);
-        showButton->setDisabled(true);
-        aboutButton->setDisabled(true);
-        downDBButton->setEnabled(true);
-
-        if(remoteNames->isEmpty())
-            upDBButton->setDisabled(true);
-
-        else upDBButton->setEnabled(true);
-
-    }
-    else {
-        themeButton->setEnabled(true);
-        dataBaseButton->setEnabled(true);
-        newRemoteButton->setEnabled(true);
-        downloadButton->setEnabled(true);
-        aboutButton->setEnabled(true);
-        downDBButton->setDisabled(true);
-        upDBButton->setDisabled(true);
-
-        if(remoteNames->isEmpty()) {
-            editButton->setDisabled(true);
-            showButton->setDisabled(true);
-            deleteButton->setDisabled(true);
-        }
-        else {
-            editButton->setEnabled(true);
-            showButton->setEnabled(true);
-            deleteButton->setEnabled(true);
-        }
-    }
 }
 
 void QtIrreco::showRemote()
 {
-    if(remoteNames->count() > 0) {
-        if(remoteButtonsVisible) { // Hides remotes
-            if(remoteNames->count() > 4) {
-                for(int i=currentRemoteButtonIndex;i<currentRemoteButtonIndex+4;i++) {
-                    buttonVector->at(i)->hide();
-                    remoteScrollBar->deleteLater();
-                }
-            }
-            if(remoteNames->count() <= 4) {
-                for(int i=0;i<remoteNames->count();i++)
-                    buttonVector->at(i)->hide();
+    if(!remoteNames->count() > 0) {
 
-            }
-            buttonVector->clear();
-            showButton->setText("Show Remotes");
-            themeButton->setEnabled(true);
-            deleteButton->setEnabled(true);
-            newRemoteButton->setEnabled(true);
-            aboutButton->setEnabled(true);
-            editButton->setEnabled(true);
-            dataBaseButton->setEnabled(true);
-            downloadButton->setEnabled(true);
-            upDBButton->setEnabled(true);
-            downDBButton->setEnabled(true);
-
-            remoteButtonsVisible = false;
-        }
-        else {
-            remoteIndex = 0;
             activeRemote.clear();
             remoteNames->clear();
 
@@ -704,9 +488,6 @@ void QtIrreco::showRemote()
                 QString line = in.readLine();
                 process_line(line);
             }
-            if(!remoteButtonsVisible && init)
-                showRemoteButtons();
-        }
     }
 }
 
@@ -830,131 +611,9 @@ void QtIrreco::process_line(QString line)
     }
 }
 
-void QtIrreco::changeRemote()
-{
-   for(int i=0;i<remoteNames->count();i++) {
-       if(buttonVector->at(i)->underMouse()) {
-            lw->clearScreen();
-            activeRemote.clear();
-            activeRemote = buttonVector->at(i)->text();
-            this->setActiveRemote();
-            this->writeRemoteChanges();
-        }
-    }
-     // hide remotes
-    if(remoteNames->count() > 4) {
-        for(int i=currentRemoteButtonIndex;i<currentRemoteButtonIndex+4;i++) {
-            buttonVector->at(i)->hide();
-            remoteScrollBar->deleteLater();
-        }
-    }
-    if(remoteNames->count() <= 4) {
-        for(int i=0;i<remoteNames->count();i++)
-            buttonVector->at(i)->hide();
-
-    }
-    remoteButtonsVisible = false;
-    showButton->setText("Show Remotes");
-    themeButton->setEnabled(true);
-    deleteButton->setEnabled(true);
-    newRemoteButton->setEnabled(true);
-    aboutButton->setEnabled(true);
-    editButton->setEnabled(true);
-    dataBaseButton->setEnabled(true);
-    downloadButton->setEnabled(true);
-    upDBButton->setEnabled(true);
-    downDBButton->setEnabled(true);
-
-    this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
-}
-
-void QtIrreco::showRemoteButtons()
-{
-    int y=0;
-    remoteIndex = 0;
-    buttonVector->clear();
-    for(int i=0;i<remoteNames->count();i++) {
-        QString rn[remoteNames->count()];
-        rn[i] = remoteNames->at(i);
-        rn[i].chop(5);
-      //  remoteNames->at(i).chop(5);
-
-        remoteButton = new QPushButton(this);
-        buttonVector->append(remoteButton);
-        if(rn[i].length() >= 12) {
-            const int fontSize = 26 - rn[i].length();
-            if(fontSize >= 7)
-                buttonVector->at(i)->setFont(QFont("sanf-serif",fontSize,0,0));
-            else buttonVector->at(i)->setFont(QFont("sanf-serif",10,0,0));
-        }
-        buttonVector->at(i)->setText(rn[i]);
-
-        connect(buttonVector->at(i), SIGNAL(clicked()), this, SLOT(changeRemote()));
-    }
-    if(remoteNames->count() <=4) {
-        for(int i=0;i<remoteNames->count();i++) {
-            buttonVector->at(i)->setGeometry(QRect(540,40+y,150,75));
-            y+=75;
-            buttonVector->at(i)->show();
-            remoteButtonsVisible = true;
-            showButton->setText("Hide Remotes");
-            deleteButton->setDisabled(true);
-            newRemoteButton->setDisabled(true);
-            aboutButton->setDisabled(true);
-            themeButton->setDisabled(true);
-            editButton->setDisabled(true);
-            dataBaseButton->setDisabled(true);
-            downloadButton->setDisabled(true);
-            upDBButton->setDisabled(true);
-            downDBButton->setDisabled(true);
-        }
-    }
-    else {
-        for(int i=0;i<4;i++) {
-            buttonVector->at(i)->setGeometry(QRect(540,40+y,150,75));
-            y+=75;
-            buttonVector->at(i)->show();
-            remoteButtonsVisible = true;
-            showButton->setText("Hide Remotes");
-            deleteButton->setDisabled(true);
-            newRemoteButton->setDisabled(true);
-            aboutButton->setDisabled(true);
-            themeButton->setDisabled(true);
-            editButton->setDisabled(true);
-            dataBaseButton->setDisabled(true);
-            downloadButton->setDisabled(true);
-            upDBButton->setDisabled(true);
-            downDBButton->setDisabled(true);
-        }
-    }
-    if(remoteNames->count() > 4) {
-        remoteScrollBar = new QScrollBar(this);
-        currentRemoteButtonIndex = 0;
-        remoteScrollBar->setGeometry(QRect(715,40,60,300));
-        connect(remoteScrollBar,SIGNAL(valueChanged(int)),this,SLOT(scrollRemoteButtons(int)));
-        remoteScrollBar->setMaximum(buttonVector->count()-4);
-        remoteScrollBar->show();
-        remoteScrollBar->setValue(0);
-    }
-}
-
-void QtIrreco::scrollRemoteButtons(int index)
-{
-    int y=0;
-    for(int i=0;i<4;i++)
-        buttonVector->at(currentRemoteButtonIndex + i)->hide();
-
-    for(int i=index;i<index+4;i++) {
-        buttonVector->at(i)->setGeometry(QRect(540,40+y,150,75));
-        y+=75;
-        buttonVector->at(i)->show();
-    }
-    currentRemoteButtonIndex = index;
-}
-
 void QtIrreco::background()
 {
-    bg = new BackgroundDlg(this);
+    bg = new BackgroundDlg(this,activeRemote);
     connect(bg,SIGNAL(backgroundChanged(int)),lw,SLOT(setBackgroundMode(int)));
     connect(bg,SIGNAL(backgroundChanged(int)),this,SLOT(changeBackground()));
     connect(bg,SIGNAL(rgbToLw(QString,QString,QString)),lw,SLOT(setRgbValues(QString,QString,QString)));
@@ -1004,6 +663,7 @@ void QtIrreco::changeBackground(QString backgroundName, QColor backgroundColor)
         lw->setAutoFillBackground(true);
     }
     else {
+
         palette.setColor(QPalette::Window,backgroundColor);
         this->setPalette(palette);
         this->setAutoFillBackground(true);
@@ -1016,112 +676,100 @@ void QtIrreco::changeBackground(QString backgroundName, QColor backgroundColor)
         lw->setAutoFillBackground(true);
     }
 }
-
-void QtIrreco::createButtons()
+void QtIrreco::initMenu()
 {
-    editButton = new QPushButton(this);
-    editButton->setObjectName(QString::fromUtf8("editButton"));
-    editButton->setText("Edit Remote");
-    editButton->setGeometry(QRect(120, 10, 200, 100));
-    newRemoteButton = new QPushButton(this);
-    newRemoteButton->setObjectName(QString::fromUtf8("newRemoteButton"));
-    newRemoteButton->setText("New Remote");
-    newRemoteButton->setGeometry(QRect(320, 10, 200, 100));
-    showButton = new QPushButton(this);
-    showButton->setObjectName(QString::fromUtf8("showButton"));
-    showButton->setText("Show Remotes");
-    showButton->setGeometry(QRect(320, 110, 200, 100));
-    downloadButton = new QPushButton(this);
-    downloadButton->setObjectName(QString::fromUtf8("downloadButton"));
-    downloadButton->setText("Download Remote");
-    downloadButton->setGeometry(QRect(120, 110, 200, 100));
-    aboutButton = new QPushButton(this);
-    aboutButton->setObjectName(QString::fromUtf8("aboutButton"));
-    aboutButton->setText("About");
-    aboutButton->setGeometry(QRect(120, 310, 200, 100));
-    deleteButton = new QPushButton(this);
-    deleteButton->setObjectName(QString::fromUtf8("deleteButton"));
-    deleteButton->setText("Delete Remote");
-    deleteButton->setGeometry(QRect(320, 210, 200, 100));
-    themeButton = new QPushButton(this);
-    themeButton->setObjectName(QString::fromUtf8("themeButton"));
-    themeButton->setText("Theme manager");
-    themeButton->setGeometry(QRect(120, 210, 200, 100));
-    dataBaseButton = new QPushButton(this);
-    dataBaseButton->setObjectName(QString::fromUtf8("dataBaseButton"));
-    dataBaseButton->setText("Remote Database");
-    dataBaseButton->setGeometry(QRect(320, 310, 200, 100));
-    downDBButton = new QPushButton(this);
-    downDBButton->setObjectName(QString::fromUtf8("downDBButton"));
-    downDBButton->setText("Download from DB");
-    downDBButton->setGeometry(QRect(540, 210, 200, 100));
-    upDBButton = new QPushButton(this);
-    upDBButton->setObjectName(QString::fromUtf8("upDBButton"));
-    upDBButton->setText("Upload to DB");
-    upDBButton->setGeometry(QRect(540, 310, 200, 100));
-    saveButton = new QPushButton(this);
-    saveButton->setObjectName(QString::fromUtf8("saveButton"));
-    saveButton->setText("Save Remote");
-    saveButton->setGeometry(QRect(120, 40, 400, 100));
-    newPushButton = new QPushButton(this);
-    newPushButton->setObjectName(QString::fromUtf8("newButton"));
-    newPushButton->setText("New Button");
-    newPushButton->setGeometry(QRect(120, 140, 200, 100));
-    snapButton = new QPushButton(this);
-    snapButton->setObjectName(QString::fromUtf8("snapButton"));
-    snapButton->setText("Snap to grid: Off");
-    snapButton->setGeometry(QRect(320, 140, 200, 100));
-    renameButton = new QPushButton(this);
-    renameButton->setObjectName(QString::fromUtf8("renameButton"));
-    renameButton->setText("Rename Remote");
-    renameButton->setGeometry(QRect(120, 240, 200, 100));
-    backgroundButton = new QPushButton(this);
-    backgroundButton->setObjectName(QString::fromUtf8("backgroundButton"));
-    backgroundButton->setText("Background");
-    backgroundButton->setGeometry(QRect(320, 240, 200, 100));
+    m_ui->menu->setTitle("");
+    m_ui->actionEditRemote->setText("Edit Remote");
+    m_ui->actionNewRemote->setText("New Remote");
+    m_ui->actionDownloadRemote->setText("Download Remote");
+    m_ui->actionSelectRemote->setText("Select Remote");
+    m_ui->actionThemeManager->setText("Theme Manager");
+    m_ui->actionDeleteRemote->setText("Delete Remote");
+    m_ui->actionAbout->setText("About");
+    m_ui->actionDownloadDb->setText("Download from DB");
+    m_ui->actionUploadDb->setText("Upload to DB");
+
+    connect(m_ui->actionEditRemote,SIGNAL(triggered()),this,SLOT(editRemote()));
+    connect(m_ui->actionNewRemote,SIGNAL(triggered()),this,SLOT(newRemote()));
+    connect(m_ui->actionDownloadRemote,SIGNAL(triggered()),this,SLOT(downloadRemote()));
+    connect(m_ui->actionSelectRemote,SIGNAL(triggered()),this,SLOT(selectRemote()));
+    connect(m_ui->actionThemeManager,SIGNAL(triggered()),this,SLOT(theme()));
+    connect(m_ui->actionDeleteRemote,SIGNAL(triggered()),this,SLOT(deleteRemote()));
+    connect(m_ui->actionAbout,SIGNAL(triggered()),this,SLOT(about()));
+    connect(m_ui->actionDownloadDb,SIGNAL(triggered()),this,SLOT(downloadDB()));
+    connect(m_ui->actionUploadDb,SIGNAL(triggered()),this,SLOT(uploadDB()));
+
+    m_ui->actionSaveRemote->setText("Save Remote");
+    m_ui->actionNewButton->setText("New Button");
+    m_ui->actionSnapToGrid->setText("Snap to grid");
+    m_ui->actionRenameRemote->setText("Rename Remote");
+    m_ui->actionBackground->setText("Background");
+
+    connect(m_ui->actionSaveRemote,SIGNAL(triggered()),this,SLOT(saveRemote()));
+    connect(m_ui->actionNewButton,SIGNAL(triggered()),this,SLOT(newButton()));
+    connect(m_ui->actionSnapToGrid,SIGNAL(triggered()),this,SLOT(snapToGrid()));
+    connect(m_ui->actionRenameRemote,SIGNAL(triggered()),this,SLOT(renameRemote()));
+    connect(m_ui->actionBackground,SIGNAL(triggered()),this,SLOT(background()));
+
+    m_ui->actionSaveRemote->setEnabled(false);
+    m_ui->actionNewButton->setEnabled(false);
+    m_ui->actionSnapToGrid->setEnabled(false);
+    m_ui->actionRenameRemote->setEnabled(false);
+    m_ui->actionBackground->setEnabled(false);
+
 }
 
-void QtIrreco::connectButtons()
+void QtIrreco::enableEditMenu()
 {
-    connect(editButton,SIGNAL(clicked()),this,SLOT(editRemote()));
-    connect(newRemoteButton, SIGNAL(clicked()),this,SLOT(newRemote()));
-    connect(showButton,SIGNAL(clicked()),this,SLOT(showRemote()));
-    connect(downloadButton,SIGNAL(clicked()),this,SLOT(downloadRemote()));
-    connect(aboutButton,SIGNAL(clicked()),this,SLOT(about()));
-    connect(deleteButton,SIGNAL(clicked()),this,SLOT(deleteRemote()));
-    connect(downDBButton,SIGNAL(clicked()),this,SLOT(downloadDB()));
-    connect(upDBButton,SIGNAL(clicked()),this,SLOT(uploadDB()));
-    connect(dataBaseButton,SIGNAL(clicked()),this,SLOT(showDBButtons()));
-    connect(renameButton,SIGNAL(clicked()),this,SLOT(renameRemote()));
-    connect(themeButton,SIGNAL(clicked()),this,SLOT(theme()));
-    connect(newPushButton,SIGNAL(clicked()),this,SLOT(newButton()));
-    connect(saveButton,SIGNAL(clicked()),this,SLOT(saveRemote()));
-    connect(backgroundButton,SIGNAL(clicked()),this,SLOT(background()));
-    connect(snapButton,SIGNAL(clicked()),this,SLOT(snapToGrid()));
+    m_ui->actionSaveRemote->setEnabled(true);
+    m_ui->actionNewButton->setEnabled(true);
+    m_ui->actionSnapToGrid->setEnabled(true);
+    m_ui->actionRenameRemote->setEnabled(true);
+    m_ui->actionBackground->setEnabled(true);
+
+    m_ui->actionEditRemote->setEnabled(false);
+    m_ui->actionNewRemote->setEnabled(false);
+    m_ui->actionDownloadRemote->setEnabled(false);
+    m_ui->actionSelectRemote->setEnabled(false);
+    m_ui->actionThemeManager->setEnabled(false);
+    m_ui->actionDeleteRemote->setEnabled(false);
+    m_ui->actionAbout->setEnabled(false);
+    m_ui->actionDownloadDb->setEnabled(false);
+    m_ui->actionUploadDb->setEnabled(false);
 }
+
+void QtIrreco::enableUseMenu()
+{
+    m_ui->actionEditRemote->setEnabled(true);
+    m_ui->actionNewRemote->setEnabled(true);
+    m_ui->actionDownloadRemote->setEnabled(true);
+    m_ui->actionSelectRemote->setEnabled(true);
+    m_ui->actionThemeManager->setEnabled(true);
+    m_ui->actionDeleteRemote->setEnabled(true);
+    m_ui->actionAbout->setEnabled(true);
+    m_ui->actionDownloadDb->setEnabled(true);
+    m_ui->actionUploadDb->setEnabled(true);
+
+    m_ui->actionSaveRemote->setEnabled(false);
+    m_ui->actionNewButton->setEnabled(false);
+    m_ui->actionSnapToGrid->setEnabled(false);
+    m_ui->actionRenameRemote->setEnabled(false);
+    m_ui->actionBackground->setEnabled(false);
+}
+
 void QtIrreco::snapToGrid()
 {
     if(lw->snapToGridEnabled)
-        snapButton->setText("Snap to grid: Off");
+        m_ui->actionSnapToGrid->setChecked(false);
+
+    else  m_ui->actionSnapToGrid->setChecked(true);
 
-    else snapButton->setText("Snap to grid: On");
 
     lw->snapToGrid();
 }
 
 void QtIrreco::addDownloadedRemote(QString remName)
 {
-    downDBButton->hide();
-    upDBButton->hide();
-    themeButton->setEnabled(true);
-    editButton->setEnabled(true);
-    dataBaseButton->setEnabled(true);
-    newRemoteButton->setEnabled(true);
-    downloadButton->setEnabled(true);
-    deleteButton->setEnabled(true);
-    showButton->setEnabled(true);
-    aboutButton->setEnabled(true);
-    showDatabaseButtons = false;
     lastTheme = false;
     QString remConf = remName;
     remConf.chop(5);
@@ -1195,10 +843,11 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         this->writeRemoteChanges();
         this->checkForRemotes();
         this->setActiveRemote();
-        this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
-        editButton->setEnabled(true);
-        showButton->setEnabled(true);
-        deleteButton->setEnabled(true);
+        this->setWindowTitle("QtIrreco:"+activeRemote);
+        m_ui->actionEditRemote->setEnabled(true);
+        m_ui->actionSelectRemote->setEnabled(true);
+        m_ui->actionDeleteRemote->setEnabled(true);
+        m_ui->actionUploadDb->setEnabled(true);
     }
     themeDownloadCount = 0;
     progress = new QProgressBar(this);
@@ -1238,10 +887,11 @@ void QtIrreco::downloadTheme()
         this->writeRemoteChanges();
         this->checkForRemotes();
         this->setActiveRemote();
-        this->setWindowTitle("QtIrreco:"+activeRemote+" - Click to hide menu");
-        editButton->setEnabled(true);
-        showButton->setEnabled(true);
-        deleteButton->setEnabled(true);
+        this->setWindowTitle("QtIrreco:"+activeRemote);
+        m_ui->actionEditRemote->setEnabled(true);
+        m_ui->actionSelectRemote->setEnabled(true);
+        m_ui->actionDeleteRemote->setEnabled(true);
+        m_ui->actionUploadDb->setEnabled(true);
         themesForRemote.clear();
         progressValue = 0;
         emit themeLoaded();
